==> smartclientcore-android-3.4.5.zip: CHANGELOG.md <==
## 3.4.5 - 2025-10-15
### Changed
- Update smartclientcore to version 6.7.0.


## 3.4.4 - 2025-09-05
### Fixed
- Audio ads without OMSDK impression tracker.


## 3.4.3 - 2025-08-28
### Changed
- Update smartclientcore to version 6.6.5.

### Fixed
- ClickThrough returns in linear case only `null`.


## 3.4.2 - 2025-07-22
### Changed
- Update smartclientcore to version 6.6.4.


## 3.4.1 - 2025-07-09
### Changed
- Update smartclientcore to version 6.6.3.


## 3.4.0 - 2025-05-14
### Added
- New properties `PublicAd.adId`, `PublicAd.adServingId`, `PublicAd.creativeIds`, `PublicAd.ids`
  `PublicAd.universalAdId` and `PublicAd.universalAdIds`.
- Second option for VMAP offset handling for VMAP via `AdPlaylistSetup.strictOffsets`.

### Changed
- Update OMSDK to 1.5.4. (getAdSessionId and getAdSessionStatePublisher from public AdSession API.)
- Update smartclientcore to version 6.6.2.


## 3.3.0 - 2024-02-09
### Fixed
- the core that it should no longer get stuck and timeout after 10 seconds when running on older tv's or devices
- a uncatched exception that was sometimes thrown on adClickThru

### Changed
- update omsdk to 1.4.11


## 3.2.5 - 2024-05-28
### Fixed
- a NullPointerException when parsing an AdBreak
- a possible NullPointerException regarding OMSDK after calling updateLastActivity


## 3.2.4 - 2024-04-09
### Changed
- update omsdk to 1.4.12

### Fixed
- a ConcurrentModificationException that was sometimes thrown when stopping adSlots


## 3.2.3 - 2023-10-26
### Added
- new static method on SmartClientCore updateLastActivity to signal to the OMS SDK when a user interacts with app via manual input

### Changed
- update smartclientcore to 6.4.8


## 3.2.2 - 2023-09-29
### Added
- new properties macroList and viewability on PublicAd

### Changed
- update smartclientcore to 6.4.6

## 3.2.1 - 2023-06-27

### Fixed
- NonLinear IFrame and HTMLResource UI Code did not run on the main thread and can cause a crash
- Implemented a safeguard feature for connect, triggering a ConnectException when encountering errors.

### Changed
- update smartclientcore to 6.4.3

## 3.2.0 - 2023-04-21

### Added
- NonLinear support for StaticResource, HTMLResource and IFrameResource
- adInfo has been extended with the `totalPlayableClips` and `totalPlayableCommercials` properties.
  These can be used to retrieve the maximum number of playable ads and the number of playable ads with the variant
  `COMMERCIAL`.
- PublicAd has been extended with linear and nonLinear properties that contain the linear and/or nonlinear ads for the current playing ad

### Fixed
- OMID verification whitelist was not checked corrently for empty/null

### Changed
- update smartclientcore to 6.4.0
- update omsdk to 1.4.4

## 3.1.2 - 2023-02-21

### Fixed
- OMID verification executed regardless of vendor whitelist.

### Changed
- update smartclientcore to 6.3.2

## 3.1.1 - 2023-01-27

### Changed
- update smartclientcore to 6.3.1

## 3.1.0 - 2023-01-19

### Added
- The `PublicAdSlot` class has been extended with the `totalPlayableClips` and `totalPlayableCommercials` properties.
  These can be used to retrieve the maximum number of playable ads and the number of playable ads with the variant
  `COMMERCIAL`.

### Changed
- update smartclientcore to 6.3.0
- changed InitException and SetupException from Throwable to type Exception

## 3.1.0-RC1 - 2023-01-11

### Added
- Native URL Handler that can be actived by setting urlhandler to URLHandler.NATIVE on GlobalConfig

### Fixed
- OMID was not started for ads after the preroll
- OMID start tracker was sometimes not correctly fired

### Changed
- Updated OMSDK to 1.4
- Updated smartclientcore to 6.2.1

## 3.0.14 - 2022-12-21

### Fixed
- a race condition between events and OMID starting resulting in missing events

## 3.0.13 - 2022-12-12

### Fixed
- OMID was not started for VMAP tags

## 3.0.12 - 2022-12-08

### Fixed
- FacadeBase.getEnvironmentVars was not correctly parsed

## 3.0.12 - 2022-12-08

### Fixed
- FacadeBase.getEnvironmentVars was not correctly parsed
 
## 3.0.11 - 2022-11-30

### Changed

- viewability config added
- Versions Info updated to show the correct version and removed the build number

### Fixed
- adInfo.universalAdId typo fixed that caused the value to be alway null

## 3.0.10 - 2022-11-11

### Changed

- desiredMimeTypes defaults updated to only include video
- Versions Info when requesting tags reduced

## 3.0.9 - 2022-10-23

- Added Readme and changelog to zip
- smartclientcore updated to 6.1.11
    #### 6.1.11 - released 2022-10-11
    ##### Changed
    - Further improvement measures.

    #### 6.1.10 - released 2022-09-22
    ##### Added
    - Extension of `GlobalConfig` with `playerHandlesNonLinear`, so that the own implementation with all NonLinear can be
    realized with other SDKs.

    ##### Changed
    - Extend documentation with info on `environmentVars.desiredBitrate`.

    ##### Fixed
    - Firefox does cancel sending XHR requests.
    - Inaccurate distinction between notViewable and viewUndetermined tracking.
    - No separation clip of type bumper although `forcePlay` is true.

## 3.0.8 - 2022-09-05

- SMARTPLR-1096 missing parameters on verification caused a crash
- smartclientcore updated to 6.1.9
   - Erroneous progress when playing a non-linear/non-linear interactive ad (VPAID).
   - Progress trackers were triggered when playing a NonLinearAd.
   - Missing measurement of visible impressions at AdStart.
   - Replacing an AdPod with an AdBuffet results in missing information under the PublicAdSlot properties.

## 3.0.7 - 2022-08-23

- Added License
- renamed zip

## 3.0.6 - 2022-07-28

- SMARTPLR-1067: VASTProperty position now correctly calculated

## 3.0.5 - 2022-07-27

- SMARTPLR-1067: adjusted OMID load event to include VASTProperties
- SMARTPLR-1067: resume is now properly tracked by OMID

## 3.0.4 - 2022-07-11

- SMARTPLR-1056: avoid sending duplicate volumeChange mediaEvents on mute/unmute

## 3.0.3 - 2022-07-07

- updated smartclientcore to 6.1.5

## 3.0.2 - 2022-07-02

- OMSDK now sets the creative type matching the ad type 
- version can now be queried immediately instead of lateinit

## 3.0.1 - 2022-06-27

- small OMSDK Integration adjustments
- friendlyObstructions request added when the session starts
- fix for mediaEvents not initialized when there are not verifications

## 3.0.0 - 2022-06-17

- complete new architecture which resembles smartclienctore-js as much as possible
- OMSDK Integration

==> smartclientcore-android-3.4.6.zip: CHANGELOG.md <==
## 3.4.6 - 2026-02-03
### Added
- `desiredReferrer` field to `GlobalConfig`.

### Changed
- Update smartclientcore to version 6.7.2.

### Fixed
- In the case of an audio ad, two impression trackers are fired.
- Prevent NPE when parsing `AdBreak` in OMID verification flow.
- Prevent NPE in Bridge.addEventListener when called from Java with null parameters.


## 3.4.5 - 2025-10-15
### Changed
- Update smartclientcore to version 6.7.0.


## 3.4.4 - 2025-09-05
### Fixed
- Audio ads without OMSDK impression tracker.


## 3.4.3 - 2025-08-28
### Changed
- Update smartclientcore to version 6.6.5.

### Fixed
- ClickThrough returns in linear case only `null`.


## 3.4.2 - 2025-07-22
### Changed
- Update smartclientcore to version 6.6.4.


## 3.4.1 - 2025-07-09
### Changed
- Update smartclientcore to version 6.6.3.


## 3.4.0 - 2025-05-14
### Added
- New properties `PublicAd.adId`, `PublicAd.adServingId`, `PublicAd.creativeIds`, `PublicAd.ids`
  `PublicAd.universalAdId` and `PublicAd.universalAdIds`.
- Second option for VMAP offset handling for VMAP via `AdPlaylistSetup.strictOffsets`.

### Changed
- Update OMSDK to 1.5.4. (getAdSessionId and getAdSessionStatePublisher from public AdSession API.)
- Update smartclientcore to version 6.6.2.


## 3.3.0 - 2024-02-09
### Fixed
- the core that it should no longer get stuck and timeout after 10 seconds when running on older tv's or devices
- a uncatched exception that was sometimes thrown on adClickThru

### Changed
- update omsdk to 1.4.11


## 3.2.5 - 2024-05-28
### Fixed
- a NullPointerException when parsing an AdBreak
- a possible NullPointerException regarding OMSDK after calling updateLastActivity


## 3.2.4 - 2024-04-09
### Changed
- update omsdk to 1.4.12

### Fixed
- a ConcurrentModificationException that was sometimes thrown when stopping adSlots


## 3.2.3 - 2023-10-26
### Added
- new static method on SmartClientCore updateLastActivity to signal to the OMS SDK when a user interacts with app via manual input

### Changed
- update smartclientcore to 6.4.8


## 3.2.2 - 2023-09-29
### Added
- new properties macroList and viewability on PublicAd

### Changed
- update smartclientcore to 6.4.6

## 3.2.1 - 2023-06-27

### Fixed
- NonLinear IFrame and HTMLResource UI Code did not run on the main thread and can cause a crash
- Implemented a safeguard feature for connect, triggering a ConnectException when encountering errors.

### Changed
- update smartclientcore to 6.4.3

## 3.2.0 - 2023-04-21

### Added
- NonLinear support for StaticResource, HTMLResource and IFrameResource
- adInfo has been extended with the `totalPlayableClips` and `totalPlayableCommercials` properties.
  These can be used to retrieve the maximum number of playable ads and the number of playable ads with the variant
  `COMMERCIAL`.
- PublicAd has been extended with linear and nonLinear properties that contain the linear and/or nonlinear ads for the current playing ad

### Fixed
- OMID verification whitelist was not checked corrently for empty/null

### Changed
- update smartclientcore to 6.4.0
- update omsdk to 1.4.4

## 3.1.2 - 2023-02-21

### Fixed
- OMID verification executed regardless of vendor whitelist.

### Changed
- update smartclientcore to 6.3.2

## 3.1.1 - 2023-01-27

### Changed
- update smartclientcore to 6.3.1

## 3.1.0 - 2023-01-19

### Added
- The `PublicAdSlot` class has been extended with the `totalPlayableClips` and `totalPlayableCommercials` properties.
  These can be used to retrieve the maximum number of playable ads and the number of playable ads with the variant
  `COMMERCIAL`.

### Changed
- update smartclientcore to 6.3.0
- changed InitException and SetupException from Throwable to type Exception

## 3.1.0-RC1 - 2023-01-11

### Added
- Native URL Handler that can be actived by setting urlhandler to URLHandler.NATIVE on GlobalConfig

### Fixed
- OMID was not started for ads after the preroll
- OMID start tracker was sometimes not correctly fired

### Changed
- Updated OMSDK to 1.4
- Updated smartclientcore to 6.2.1

## 3.0.14 - 2022-12-21

### Fixed
- a race condition between events and OMID starting resulting in missing events

## 3.0.13 - 2022-12-12

### Fixed
- OMID was not started for VMAP tags

## 3.0.12 - 2022-12-08

### Fixed
- FacadeBase.getEnvironmentVars was not correctly parsed

## 3.0.12 - 2022-12-08

### Fixed
- FacadeBase.getEnvironmentVars was not correctly parsed
 
## 3.0.11 - 2022-11-30

### Changed

- viewability config added
- Versions Info updated to show the correct version and removed the build number

### Fixed
- adInfo.universalAdId typo fixed that caused the value to be alway null

## 3.0.10 - 2022-11-11

### Changed

- desiredMimeTypes defaults updated to only include video
- Versions Info when requesting tags reduced

## 3.0.9 - 2022-10-23

- Added Readme and changelog to zip
- smartclientcore updated to 6.1.11
    #### 6.1.11 - released 2022-10-11
    ##### Changed
    - Further improvement measures.

    #### 6.1.10 - released 2022-09-22
    ##### Added
    - Extension of `GlobalConfig` with `playerHandlesNonLinear`, so that the own implementation with all NonLinear can be
    realized with other SDKs.

    ##### Changed
    - Extend documentation with info on `environmentVars.desiredBitrate`.

    ##### Fixed
    - Firefox does cancel sending XHR requests.
    - Inaccurate distinction between notViewable and viewUndetermined tracking.
    - No separation clip of type bumper although `forcePlay` is true.

## 3.0.8 - 2022-09-05

- SMARTPLR-1096 missing parameters on verification caused a crash
- smartclientcore updated to 6.1.9
   - Erroneous progress when playing a non-linear/non-linear interactive ad (VPAID).
   - Progress trackers were triggered when playing a NonLinearAd.
   - Missing measurement of visible impressions at AdStart.
   - Replacing an AdPod with an AdBuffet results in missing information under the PublicAdSlot properties.

## 3.0.7 - 2022-08-23

- Added License
- renamed zip

## 3.0.6 - 2022-07-28

- SMARTPLR-1067: VASTProperty position now correctly calculated

## 3.0.5 - 2022-07-27

- SMARTPLR-1067: adjusted OMID load event to include VASTProperties
- SMARTPLR-1067: resume is now properly tracked by OMID

## 3.0.4 - 2022-07-11

- SMARTPLR-1056: avoid sending duplicate volumeChange mediaEvents on mute/unmute

## 3.0.3 - 2022-07-07

- updated smartclientcore to 6.1.5

## 3.0.2 - 2022-07-02

- OMSDK now sets the creative type matching the ad type 
- version can now be queried immediately instead of lateinit

## 3.0.1 - 2022-06-27

- small OMSDK Integration adjustments
- friendlyObstructions request added when the session starts
- fix for mediaEvents not initialized when there are not verifications

## 3.0.0 - 2022-06-17

- complete new architecture which resembles smartclienctore-js as much as possible
- OMSDK Integration
